==> estateplat-common-1.2.4-20200120.020913-255-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslHsSys.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2020/1/20
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:chenjia@gtmap.cn">chenjia</a>
*@Description: 核税系统的三要素
*@Date 10:19 2020/1/20
*/
@Entity
@Table( name ="YCSL_HS_SYS" )
public class YcslHsSys implements Serializable {
    /**
     * 三要素ID
     */
    @Column(name = "SYSID" )
    @Id
    private String sysid;
    /**
     * 交易id
     */
    @Column(name = "JYUUID" )
    private String jyuuid;
    /**
     * 税务机关代码
     */
    @Column(name = "SWJGDM" )
    private Double swjgdm;
    /**
     * 纳税人识别号
     */
    @Column(name = "NSRSBH" )
    private Double nsrsbh;
    /**
     * 税票号码
     */
    @Column(name = "DZSPHM" )
    private Double dzsphm;

    public String getSysid() {
        return sysid;
    }

    public void setSysid(String sysid) {
        this.sysid = sysid;
    }

    public String getJyuuid() {
        return jyuuid;
    }

    public void setJyuuid(String jyuuid) {
        this.jyuuid = jyuuid;
    }

    public Double getSwjgdm() {
        return swjgdm;
    }

    public void setSwjgdm(Double swjgdm) {
        this.swjgdm = swjgdm;
    }

    public Double getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(Double nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public Double getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(Double dzsphm) {
        this.dzsphm = dzsphm;
    }
}

==> estateplat-common-1.2.4-20201118.062222-517-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslHsSys.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2020/1/20
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:chenjia@gtmap.cn">chenjia</a>
*@Description: 核税系统的三要素
*@Date 10:19 2020/1/20
*/
@Entity
@Table( name ="YCSL_HS_SYS" )
public class YcslHsSys implements Serializable {
    /**
     * 三要素ID
     */
    @Column(name = "SYSID" )
    @Id
    private String sysid;
    /**
     * 交易id
     */
    @Column(name = "JYUUID" )
    private String jyuuid;
    /**
     * 税务机关代码
     */
    @Column(name = "SWJGDM" )
    private String swjgdm;
    /**
     * 纳税人识别号
     */
    @Column(name = "NSRSBH" )
    private String nsrsbh;
    /**
     * 税票号码
     */
    @Column(name = "DZSPHM" )
    private String dzsphm;

    public String getSysid() {
        return sysid;
    }

    public void setSysid(String sysid) {
        this.sysid = sysid;
    }

    public String getJyuuid() {
        return jyuuid;
    }

    public void setJyuuid(String jyuuid) {
        this.jyuuid = jyuuid;
    }

    public String getSwjgdm() {
        return swjgdm;
    }

    public void setSwjgdm(String swjgdm) {
        this.swjgdm = swjgdm;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }
}
